;; Generated package description from altcaps.el  -*- no-byte-compile: t -*-
(define-package "altcaps" "1.3.0.0.20260111.105148" "Apply alternating letter casing to convey sarcasm or mockery" '((emacs "27.1")) :commit "57ba7c4decdca89ed10d1b8772c74e936bdf6736" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/altcaps")
